Type Alias AxisId
pub type AxisId = u32;Available on crate feature
winit only.Expand description
Identifier for a specific analog axis on some device.
pub type AxisId = u32;winit only.Identifier for a specific analog axis on some device.